@@ -16,7 +16,7 @@ ebic.glm.bsreg <- function(target, dataset, wei = NULL, gam = NULL, type = "logi
   n <- dm[1]  ## sample size 
   p <- dm[2]  ## number of variables
   if ( p > n ) {
-    res <- paste("The number of variables is hiher than the sample size. No backward procedure was attempted")
+    res <- paste("The number of variables is higher than the sample size. No backward procedure was attempted")
     
   } else {
     
@@ -30,7 +30,7 @@ ebic.glm.bsreg <- function(target, dataset, wei = NULL, gam = NULL, type = "logi
     tool <- numeric(p + 1)
     
     ini <- glm( target ~.,  data = dataset, family = oiko, weights = wei )
-    bic0 <-  BIC(ini)   ## initial BIC  
+    bic0 <-  BIC(ini)   ## initial bic  
     tool[1] <- bic0
     bic <- numeric(p)
     M <- dim(dataset)[2] - 1
@@ -46,8 +46,8 @@ ebic.glm.bsreg <- function(target, dataset, wei = NULL, gam = NULL, type = "logi
         mat <- matrix(0, nrow = 0, ncol = 2 )
       }
       runtime <- proc.time() - tic
-      colnames(info) <- c("Variables", "BIC")
-      colnames(mat) <- c("Variables", "BIC")
+      colnames(info) <- c("Variables", "eBIC")
+      colnames(mat) <- c("Variables", "eBIC")
       res <- list(runtime = runtime, info = info, mat = mat )
       
     } else { 
@@ -60,8 +60,8 @@ ebic.glm.bsreg <- function(target, dataset, wei = NULL, gam = NULL, type = "logi
     mat <- cbind(1:p, bic )
     sel <- which.min( mat[, 2] )
     info <- matrix( c(0, 0), ncol = 2 )
-    colnames(info) <- c("Variables", "BIC")
-    colnames(mat) <- c("Variables", "BIC")
+    colnames(info) <- c("Variables", "eBIC")
+    colnames(mat) <- c("Variables", "eBIC")
     
     if ( bic0 - mat[sel, 2] < 0  ) {
       runtime <- proc.time() - tic
