@@ -12,30 +12,21 @@ gammafsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshold =
   moda <- list()
   k <- 1   ## counter
   tool <- numeric( min(n, p) )
+  threshold <- log(threshold)
 
-  if ( is.null(iniset) ) {
-    da <- 0
-    pa <- 0
-  } else {
-    pa <- NCOL(iniset)
-    da <- 1:pa
-    dataset <- cbind(iniset, dataset)
-  }  
-  
-    runtime <- proc.time()
+  pa <- NCOL(iniset)
+  da <- 1:pa
+  dataset <- cbind(iniset, dataset)
+  runtime <- proc.time()
     
     devi = dof = numeric(p)
-    if ( pa == 0 ) {
-      ini <- 2 * logLik( glm( target ~ 1, weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE ) )
-      do <- 1
-    } else  {
-      mi <- glm(target ~., data = as.data.frame( iniset ), weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
-      do <- length( mi$coefficients )
-      ini <- 2 * as.numeric( logLik(mi) ) 
-    }
+    mi <- glm(target ~., data = as.data.frame( iniset ), weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
+    do <- length( mi$coefficients )
+    ini <- 2 * as.numeric( logLik(mi) ) 
+    
     if (ncores <= 1) {
       for (i in 1:p) {
-        mi <- glm( target ~ . , as.data.frame( dataset[, c(da, pa + i)] ), weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
+        mi <- glm( target ~ . , data = dataset[, c(da, pa + i)], weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
         devi[i] <- 2 * as.numeric( logLik(mi) )
         dof[i] <- length( mi$coefficients ) 
       }
@@ -48,7 +39,7 @@ gammafsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshold =
       cl <- makePSOCKcluster(ncores)
       registerDoParallel(cl)
       mod <- foreach( i = 1:p, .combine = rbind) %dopar% {
-        ww <- glm( target ~., data = as.data.frame( dataset[, c(da, pa + i)] ), weights = wei, family = Gamma(link = log) )
+        ww <- glm( target ~., data = dataset[, c(da, pa + i)], weights = wei, family = Gamma(link = log) )
         return( c( 2 * as.numeric( logLik(ww) ), length( ww$coefficients ) ) )
       }
       
@@ -58,40 +49,35 @@ gammafsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshold =
     }
     
     mat <- cbind(1:p, pval, stat) 
-    
     colnames(mat)[1] <- "variables"
     rownames(mat) <- 1:p
-    
     sel <- which.min(pval)
     info <- matrix( c( 1e300, 0, 0 ), ncol = 3 )
-    sela <- sel
+    sela <- pa + sel
     
     if ( mat[sel, 2] < threshold ) {
       info[k, ] <- mat[sel, ]
       mat <- mat[-sel, , drop = FALSE] 
       #if ( robust == FALSE ) {
-      mi <- glm( target ~., data = as.data.frame( dataset[, c(da, sel) ] ), weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
+      mi <- glm( target ~., data = dataset[, c(da, sela) ], weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
       tool[k] <- BIC( mi )
       moda[[ k ]] <- mi
     }
-    
     ############
     ###       k equals 2
     ############ 
-    
     if ( info[k, 2] < threshold  &  nrow(mat) > 0 ) {
       
       k <- k + 1
       pn <- p - k + 1   
-      
       ini <- 2 * as.numeric( logLik(moda[[ 1 ]]) )
       do <- length( coef( moda[[ 1 ]]  ) ) 
+      devi <- dof <- numeric( pn )  
       
       if ( ncores <= 1 ) {
-        devi <- dof <- numeric(pn)
         #if ( robust == FALSE ) {  ## Non robust
         for ( i in 1:pn ) {
-          ww <- glm( target ~., data = as.data.frame( dataset[, c(da, sela, mat[pa + i, 1]) ] ), weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
+          ww <- glm( target ~., data = dataset[, c(da, sela, pa + mat[i, 1]) ], weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
           devi[i] <- 2 * as.numeric( logLik(ww) )
           dof[i] <- length( ww$coefficients )          
         }
@@ -103,7 +89,7 @@ gammafsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshold =
         cl <- makePSOCKcluster(ncores)
         registerDoParallel(cl)
         mod <- foreach( i = 1:pn, .combine = rbind) %dopar% {
-          ww <- glm( target ~., data = as.data.frame( dataset[, c(da, sela, mat[pa + i, 1]) ] ), weights = wei, family = Gamma(link = log) )
+          ww <- glm( target ~., data = dataset[, c(da, sela, pa + mat[i, 1]) ], weights = wei, family = Gamma(link = log) )
           return( c( 2 * as.numeric( logLik(ww) ), length( coef( ww ) ) ) )
         }
         stopCluster(cl)
@@ -113,10 +99,10 @@ gammafsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshold =
       
       mat[, 2:3] <- cbind(pval, stat)
       ina <- which.min(mat[, 2])
-      sel <- mat[ina, 1]    
+      sel <- pa + mat[ina, 1]    
       
       if ( mat[ina, 2] < threshold ) {
-        ma <- glm( target ~., data=as.data.frame( dataset[, c(da, sela, sel) ] ), weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
+        ma <- glm( target ~., data = dataset[, c(da, sela, sel) ], weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
         tool[k] <- BIC( ma )
 
         if ( tool[ k - 1 ] - tool[ k ] <= tol ) {
@@ -124,7 +110,7 @@ gammafsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshold =
           
         } else { 
           info <- rbind(info, c( mat[ina, ] ) )
-          sela <- info[, 1]
+          sela <- c(sela, sel)
           mat <- mat[-ina , , drop = FALSE] 
           moda[[ k ]] <- ma
         }
@@ -142,14 +128,13 @@ gammafsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshold =
         
         ini <- 2 * as.numeric( logLik(moda[[ k ]]) ) 
         do <- length( coef( moda[[ k ]]  ) ) 
-        
         k <- k + 1   
         pn <- p - k  + 1
+        devi <- dof <- numeric( pn )  
         
         if (ncores <= 1) {  
-          devi = dof = numeric(pn) 
           for ( i in 1:pn ) {
-            ma <- glm( target ~., data = as.data.frame( dataset[, c(da, sela, mat[pa + i, 1] ) ] ), weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
+            ma <- glm( target ~., data = dataset[, c(da, sela, pa + mat[i, 1] ) ], weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
             devi[i] <- 2 * as.numeric( logLik(ma) )
             dof[i] <- length( ma$coefficients ) 
           }
@@ -161,7 +146,7 @@ gammafsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshold =
           cl <- makePSOCKcluster(ncores)
           registerDoParallel(cl)
           mod <- foreach( i = 1:pn, .combine = rbind) %dopar% {
-            ww <- glm( target ~., data = as.data.frame( dataset[, c(da, sela, mat[pa + i, 1]) ] ), weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
+            ww <- glm( target ~., data = dataset[, c(da, sela, pa + mat[i, 1]) ], weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
             return( c( 2 * as.numeric( logLik(ww) ), length( ww$coefficients ) ) )
           }
           
@@ -172,17 +157,17 @@ gammafsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshold =
         
         mat[, 2:3] <- cbind(pval, stat)
         ina <- which.min(mat[, 2])
-        sel <- mat[ina, 1]    
+        sel <- pa + mat[ina, 1]    
         
         if ( mat[ina, 2] < threshold ) {
-          ma <- glm( target ~., data = as.data.frame( dataset[, c(da, sela, sel) ] ), weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
+          ma <- glm( target ~., data = dataset[, c(da, sela, sel) ], weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
           tool[k] <- BIC( ma )
           if ( tool[ k - 1 ] - tool[ k  ] < tol ) {
             info <- rbind(info, c( 1e300, 0, 0 ) )
             
           } else { 
             info <- rbind( info, mat[ina, ] )
-            sela <- info[, 1]
+            sela <- c(sela, sel)
             mat <- mat[-ina, , drop = FALSE]
             moda[[ k ]] <- ma
           } 
@@ -203,7 +188,7 @@ gammafsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshold =
       info <- NULL
       
     } else {
-        final <- glm( target ~., data = as.data.frame( dataset[, c(da, sela) ] ), weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
+        final <- glm( target ~., data = dataset[, c(da, sela) ], weights = wei, family = Gamma(link = log), y = FALSE, model = FALSE )
         info <- info[1:d, , drop = FALSE]
         info <- cbind( info, tool[ 1:d ] ) 
         colnames(info) <- c( "variables", "log.p-value", "stat", "BIC" )
