@@ -89,16 +89,16 @@ testIndGamma = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo =
   if (length(cs) == 0)  {
     fit1 <- glm(target ~ 1, family = Gamma(link = log), weights = wei ,model = FALSE)
     fit2 <- glm(target ~ x, family = Gamma(link = log), weights = wei ,model = FALSE)
-    stat <- 2  * as.numeric(logLik(fit2) )  - 2  * as.numeric(logLik(fit1) ) 
-    dof <- length( coef(fit2) ) - 1   
   } else {
     #if ( robust == FALSE ) {
     fit1 = glm(target ~., data = as.data.frame( dataset[, csIndex] ), family = Gamma(link = log), weights = wei, model = FALSE)
     fit2 = glm(target ~., data = as.data.frame( dataset[, c(csIndex, xIndex)] ), family = Gamma(link = log), weights = wei, model = FALSE)
-    stat <- 2  * as.numeric(logLik(fit2) )  - 2  * as.numeric(logLik(fit1) ) 
-    dof <- length( coef(fit2) ) - length( coef(fit1) )
   } 
-  pvalue = pchisq( stat, dof, lower.tail = FALSE, log.p = TRUE ) 
+  mod <- anova(fit1, fit2, test = "F")
+  stat <- mod[2, 5]
+  df1 <- mod[2, 3]
+  df2 <- mod[2, 1]
+  pvalue = pf( stat, df1, df2, lower.tail = FALSE, log.p = TRUE ) 
   flag = 1;
   
   #last error check
